Coverage for tests/utils.py: 100%

1 import typing (empty)

2

3 from hypothesis import strategies as st (empty)

4

5 import swiift.model.frac_handlers as fh (empty)

6

7

8 class FloatsKWA(typing.TypedDict, total=False): (empty)

9 allow_nan: bool (empty)

10 allow_infinity: bool (empty)

11 allow_subnormal: bool (empty)

12

13

14 FloatSt = st.SearchStrategy[float] (empty)

15 float_kw: FloatsKWA = { (empty)

16 "allow_nan": False,

17 "allow_subnormal": False,

18}

19 fracture_handler_types = ( (empty)

20 fh.BinaryFracture,

21 fh.BinaryStrainFracture,

22 fh.MultipleStrainFracture,

23)